@@ -36,10 +36,6 @@ impl MsgTimeoutOnClose {
             signer,
         }
     }
-
-    pub fn proofs(&self) -> &Proofs {
-        &self.proofs
-    }
 }
 
 impl Msg for MsgTimeoutOnClose {
