@@ -5,7 +5,7 @@
 use core::fmt;
 use serde_derive::{Deserialize, Serialize};
 
-use crate::applications::{ics20_fungible_token_transfer, ics27_interchain_accounts};
+use crate::applications::ics20_fungible_token_transfer;
 use crate::prelude::*;
 
 /// The version field for a `ChannelEnd`.
@@ -21,10 +21,6 @@ impl Version {
         Self(ics20_fungible_token_transfer::VERSION.to_string())
     }
 
-    pub fn ics27() -> Self {
-        Self(ics27_interchain_accounts::VERSION.to_string())
-    }
-
     pub fn empty() -> Self {
         Self("".to_string())
     }
