@@ -1,5 +1,4 @@
 use ibc_proto::ibc::core::commitment::v1::MerkleProof;
-use tendermint::Time;
 
 use crate::core::ics02_client::client_consensus::AnyConsensusState;
 use crate::core::ics02_client::client_def::ClientDef;
@@ -32,7 +31,6 @@ impl ClientDef for MockClient {
 
     fn check_header_and_update_state(
         &self,
-        _now: Time,
         _ctx: &dyn ClientReader,
         _client_id: ClientId,
         client_state: Self::ClientState,
