@@ -1,7 +1,7 @@
 use tendermint::abci::transaction::Hash;
 
-use crate::ics02_client::client_consensus::QueryClientEventRequest;
-use crate::ics04_channel::channel::QueryPacketEventDataRequest;
+use crate::core::ics02_client::client_consensus::QueryClientEventRequest;
+use crate::core::ics04_channel::channel::QueryPacketEventDataRequest;
 
 /// Used for queries and not yet standardized in channel's query.proto
 #[derive(Clone, Debug)]
@@ -11,5 +11,10 @@ pub enum QueryTxRequest {
     Transaction(QueryTxHash),
 }
 
+#[derive(Clone, Debug)]
+pub enum QueryBlockRequest {
+    Packet(QueryPacketEventDataRequest),
+}
+
 #[derive(Clone, Debug)]
 pub struct QueryTxHash(pub Hash);
